class DialogueGame {
  constructor() {
    this.dialogueText = document.querySelector('.dialogue-text');
    this.characterName = document.querySelector('.character-name');
    this.choiceButtons = document.querySelector('.choice-buttons');
    this.karmaValue = document.querySelector('.karma-value');
    this.levelValue = document.querySelector('.level-value');
    
    this.karma = 0;
    this.currentScene = 0;
    this.cultivationLevels = [
      'Qi Condensation',
      'Foundation Establishment',
      'Core Formation',
      'Nascent Soul',
      'Immortal Ascension'
    ];
    
    this.dialogues = [
      {
        character: 'Elder Ming',
        text: 'Young cultivator, I sense potential within you. Would you like to begin your journey on the immortal path?',
        choices: [
          { text: 'Yes, I wish to pursue immortality', karma: 5 },
          { text: 'I prefer to learn more first', karma: 3 },
          { text: 'I have no interest in cultivation', karma: -2 }
        ]
      }
      // Add more dialogue scenes here
    ];
    
    this.initGame();
  }
  
  initGame() {
    this.showScene(0);
    this.updateStats();
  }
  
  showScene(sceneIndex) {
    const scene = this.dialogues[sceneIndex];
    this.characterName.textContent = scene.character;
    this.dialogueText.textContent = scene.text;
    
    this.choiceButtons.innerHTML = '';
    scene.choices.forEach((choice, index) => {
      const button = document.createElement('button');
      button.textContent = choice.text;
      button.addEventListener('click', () => this.makeChoice(index, choice));
      this.choiceButtons.appendChild(button);
    });
  }
  
  makeChoice(choiceIndex, choice) {
    this.karma += choice.karma;
    this.updateStats();
    // Add logic for progressing to next scene
  }
  
  updateStats() {
    this.karmaValue.textContent = this.karma;
    const cultivationIndex = Math.floor(this.karma / 10);
    this.levelValue.textContent = this.cultivationLevels[
      Math.min(cultivationIndex, this.cultivationLevels.length - 1)
    ];
  }
}

document.addEventListener('DOMContentLoaded', () => {
  const game = new DialogueGame();
});
